@@ -9,6 +9,8 @@ from .errors import (
 import docker
 import time
 import typer
+import os
+from read_version import read_version
 
 
 class Service:
@@ -137,9 +139,9 @@ class Service:
                         "traefik.http.middlewares.default-headers.headers.sslRedirect": "true",
                         "traefik.http.middlewares.default-headers.headers.browserXssFilter": "true",
                         "traefik.http.middlewares.default-headers.headers.contentTypeNosniff": "true",
-                        "traefik.http.middlewares.default-headers.headers.forceSTSHeader": "true",
-                        "traefik.http.middlewares.default-headers.headers.stsIncludeSubdomains": "true",
-                        "traefik.http.middlewares.default-headers.headers.stsPreload": "true",
+                        "traefik.http.middlewares.default-headers.headers.forceSTSHeader": "false",
+                        "traefik.http.middlewares.default-headers.headers.stsIncludeSubdomains": "false",
+                        "traefik.http.middlewares.default-headers.headers.stsPreload": "false",
                         "traefik.http.middlewares.default-headers.headers.sslProxyHeaders.X-FORWARDED-PROTO": "https",
                         "traefik.http.routers.traefik-secured.service": "api@internal",
                         "traefik.http.routers.traefik-secured.tls": "true",
@@ -189,7 +191,40 @@ class Service:
             }
 
         elif self.name == "backplane":
-            pass
+            self.attrs = {
+                "image": f"wearep3r/backplane:{read_version('.', '__init__.py')}",
+                "auto_remove": False,
+                "detach": True,
+                "command": "ssh",
+                "hostname": "backplane",
+                "labels": {},
+                "name": "backplane",
+                "network": "backplane",
+                "ports": {"2222/tcp": 2222},
+                "environment": {
+                    "BACKPLANE_DOMAIN": self.config.domain,
+                    "BACKPLANE_MAIL": self.config.mail,
+                },
+                "restart_policy": {"Name": "on-failure", "MaximumRetryCount": 5},
+                "volumes": {
+                    f"{os.path.join(os.getenv('HOME'),'.ssh')}": {
+                        "bind": "/backplane/.ssh",
+                        "mode": "rw",
+                    },
+                    "backplane-repositories": {
+                        "bind": "/backplane/repositories",
+                        "mode": "rw",
+                    },
+                    f"{os.path.join(self.config.config_dir)}": {
+                        "bind": "/backplane/.backplane",
+                        "mode": "rw",
+                    },
+                    "/var/run/docker.sock": {
+                        "bind": "/var/run/docker.sock",
+                        "mode": "rw",
+                    },
+                },
+            }
 
         else:
             raise ServiceNotFound(f"service {self.name} does not exist")
@@ -229,8 +264,12 @@ class Service:
         if self.container:
             if self.container.attrs["State"]["Status"] == "running":
                 message_status = typer.style("running", fg=typer.colors.GREEN, bold=True)
-                url_prefix = "https://" if self.config.https else "http://"
-                message_info = typer.style(f" ({url_prefix}{self.url})")
+
+                if self.name != "backplane":
+                    url_prefix = "https://" if self.config.https else "http://"
+                    message_info = typer.style(f" ({url_prefix}{self.url})")
+                else:
+                    message_info = ""
             elif self.container.attrs["State"]["Status"] == "starting":
                 message_status = typer.style(
                     "starting", fg=typer.colors.WHITE, bg=typer.colors.BLUE
@@ -313,8 +352,13 @@ class Service:
                     # Remove volumes
                     docker_client = docker.from_env()
 
-                    volume = docker_client.volumes.get(f"{self.name}-data")
-                    volume.remove(force=True)
+                    volumes = docker_client.volumes.list(filters={"name": self.name})
+
+                    if volumes:
+                        for volume in volumes:
+                            if volume.attrs["Name"].strip("/") == f"{self.name}-data":
+                                # volume = docker_client.volumes.get(f"{self.name}-data")
+                                volume.remove(force=True)
             except Exception as e:
                 raise CannotRemoveService(
                     f"Unable to remove container for service {self.name}: {e}"
